## [1.0.3](https://github.com/haru52/convertflac/compare/v1.0.2...v1.0.3) (2023-03-31)


### Bug Fixes

* **chore:** change the order of options in help message ([6d2ae47](https://github.com/haru52/convertflac/commit/6d2ae47cd1e7113177667d070778c605ae706728))

## [1.0.2](https://github.com/haru52/convertflac/compare/v1.0.1...v1.0.2) (2023-03-31)


### Bug Fixes

* **docs:** update README.md ([93f03ed](https://github.com/haru52/convertflac/commit/93f03edd5cd8d8bd39a868c63bb73864f477ee30))

## [1.0.1](https://github.com/haru52/convertflac/compare/v1.0.0...v1.0.1) (2023-03-31)


### Bug Fixes

* fix the bug ([3f6beee](https://github.com/haru52/convertflac/commit/3f6beee261ddc038d4ba3c1595ad586efdac0d9b))

## 1.0.0 (2023-03-31)


### Features

* release initial version ([8ba69b9](https://github.com/haru52/convertflac/commit/8ba69b983e5766130c5afb64e5ecf8b9e24e5994))
